@@ -91,7 +91,7 @@ gpm_brightness_xrandr_output_get_internal (GpmBrightnessXRandR *brightness, RROu
 {
 	unsigned long nitems;
 	unsigned long bytes_after;
-	unsigned char *prop;
+	guint *prop;
 	Atom actual_type;
 	int actual_format;
 	gboolean ret = FALSE;
@@ -101,7 +101,7 @@ gpm_brightness_xrandr_output_get_internal (GpmBrightnessXRandR *brightness, RROu
 	if (XRRGetOutputProperty (brightness->priv->dpy, output, brightness->priv->backlight,
 				  0, 4, False, False, None,
 				  &actual_type, &actual_format,
-				  &nitems, &bytes_after, &prop) != Success) {
+				  &nitems, &bytes_after, ((unsigned char **)&prop)) != Success) {
 		egg_debug ("failed to get property");
 		return FALSE;
 	}
@@ -720,13 +720,13 @@ gpm_brightness_xrandr_init (GpmBrightnessXRandR *brightness)
 
 	/* can we do this */
 	brightness->priv->has_extension = gpm_brightness_xrandr_setup_display (brightness);
+#if (RANDR_MAJOR == 1 && RANDR_MINOR >= 3)
+	brightness->priv->has_randr13 = gpm_brightness_xrandr_setup_version (brightness);
+#endif
 	if (brightness->priv->has_extension == FALSE) {
 		egg_debug ("no XRANDR extension, so aborting init");
 		return;
 	}
-#if (RANDR_MAJOR == 1 && RANDR_MINOR >= 3)
-	brightness->priv->has_randr13 = gpm_brightness_xrandr_setup_version (brightness);
-#endif
 
 	screen = gdk_screen_get_default ();
 	window = gdk_screen_get_root_window (screen);
